# $Id: pkgIndex.tcl.in,v 1.7 2004/01/03 03:33:04 airwin Exp $

# Load PLplot tcl extension

# This proc takes care of finding & loading the proper driver.

# The original version dealt with the possibility that either or both $dir and
# $file may contain spaces, or characters like []{}, but this hasn't been
# tested for this version.

proc load_pkg_Pltcl {dir} {
    global pllibrary tcl_platform auto_path
    #puts "loading Pltcl, dir: $dir"
    set pllibrary $dir

    if {$tcl_platform(platform) == "unix"} {
	set thisDir [pwd]
	set buildDir /root/plplot/plplot-5.2.1.cvs.20040104
	set bLen [string length $buildDir] 
	if {![string compare -length $bLen $buildDir $thisDir]}	then { 
		set searchdirs ".libs"} else {
		set searchdirs "/usr/lib"}
	#puts $searchdirs
	# prefer double precision version
	set dlnames "libplplottcltkd.so.9 libplplottcltk.so.9";
	set file ""
	foreach reldir $searchdirs {
	    foreach dlname $dlnames {
		set driver [file join $dir $reldir $dlname]
		#puts "looking for driver file: $driver"
		if [file exists $driver] {
		    set file $driver
		    break
		}
	    }
	    if { $file != "" } { break }
	}
	if { $file == "" } {
	    error "load_pkg_Pltcl: could not find loadable driver"
	}

    } else {
    # This is probably broken, someone should fix it.
	if {[info exists tcl_platform(debug)]} {
	    set file [file join $dir plplot510d[info sharedlibextension]]
	} else {
	    set file [file join $dir plplot510[info sharedlibextension]]
	}
    }

    load $file Pltcl
# put core tcl scripts in path
    lappend auto_path $dir/tcl
    rename load_pkg_Pltcl {}
}

package ifneeded Pltcl 5 [list load_pkg_Pltcl $dir]

# $Id: pkgIndex.tcl.in,v 1.9 2004/01/03 03:33:04 airwin Exp $

# Load PLplot tk extension

# This proc takes care of finding & loading the proper driver.

# The original version dealt with the possibility that either or both $dir and
# $file may contain spaces, or characters like []{}, but this hasn't been
# tested for this version.

proc load_pkg_Pltk {dir} {
    global pllibrary tcl_platform auto_path
    #puts "loading Pltk, dir: $dir"
    set pllibrary $dir

    if {$tcl_platform(platform) == "unix"} {
	set stem tk
	set thisDir [pwd]
	set buildDir /root/plplot/plplot-5.2.1.cvs.20040104
	set bLen [string length $buildDir] 
	if {![string compare -length $bLen $buildDir $thisDir]}	then { 
		set searchdirs "../../drivers/.libs"} else {
		set searchdirs "/usr/lib/plplot5.2.1.cvs.20040104/driversd"}
	#puts $searchdirs
	set suf [info sharedlibextension]

	set file ""
	foreach reldir $searchdirs {
	    set driver [file join $dir $reldir $stem$suf]
	    #puts "looking for driver file: $driver"
	    if [file exists $driver] {
	        set file $driver
	        break
	    }
	    if { $file != "" } { break }
	}
	if { $file == "" } {
	# Dynamic driver location failed, now try static driver location.
	set searchdirs "/usr/lib";
	# prefer double precision version
	set dlnames "libplplotd.so.9 libplplot.so.9";
	set file ""
	foreach reldir $searchdirs {
	    foreach dlname $dlnames {
		set driver [file join $dir $reldir $dlname]
		#puts "looking for driver file: $driver"
		if [file exists $driver] {
		    set file $driver
		    break
		}
	    }
	    if { $file != "" } { break }
	}
	}
	if { $file == "" } {
	    error "load_pkg_Pltk: could not find loadable driver"
	}

    } else {
    # This is probably broken, someone should fix it.
	if {[info exists tcl_platform(debug)]} {
	    set file [file join $dir plplot510d[info sharedlibextension]]
	} else {
	    set file [file join $dir plplot510[info sharedlibextension]]
	}
    }

    load $file Pltk
# put core tcl scripts in path
    lappend auto_path $dir/tcl
    rename load_pkg_Pltk {}
}

package ifneeded Pltk 5 [list load_pkg_Pltk $dir]
# $Id: pkgIndex.tcl.in,v 1.9 2004/01/03 03:33:04 airwin Exp $

# Load PLplot tkwin extension

# This proc takes care of finding & loading the proper driver.

# The original version dealt with the possibility that either or both $dir and
# $file may contain spaces, or characters like []{}, but this hasn't been
# tested for this version.

proc load_pkg_Plplotter {dir} {
    global pllibrary tcl_platform auto_path
    #puts "loading Plplotter, dir: $dir"
    set pllibrary $dir

    if {$tcl_platform(platform) == "unix"} {
	set stem tkwin
	set thisDir [pwd]
	set buildDir /root/plplot/plplot-5.2.1.cvs.20040104
	set bLen [string length $buildDir] 
	if {![string compare -length $bLen $buildDir $thisDir]}	then { 
		set searchdirs "../../drivers/.libs"} else {
		set searchdirs "/usr/lib/plplot5.2.1.cvs.20040104/driversd"}
	#puts $searchdirs
	set suf [info sharedlibextension]

	set file ""
	foreach reldir $searchdirs {
	    set driver [file join $dir $reldir $stem$suf]
	    #puts "looking for driver file: $driver"
	    if [file exists $driver] {
	        set file $driver
	        break
	    }
	    if { $file != "" } { break }
	}
	if { $file == "" } {
	# Dynamic driver location failed, now try static driver location.
	set searchdirs "/usr/lib";
	# prefer double precision version
	set dlnames "libplplotd.so.9 libplplot.so.9";
	set file ""
	foreach reldir $searchdirs {
	    foreach dlname $dlnames {
		set driver [file join $dir $reldir $dlname]
		#puts "looking for driver file: $driver"
		if [file exists $driver] {
		    set file $driver
		    break
		}
	    }
	    if { $file != "" } { break }
	}
	}
	if { $file == "" } {
	    error "load_pkg_Plplotter: could not find loadable driver"
	}

    } else {
    # This is probably broken, someone should fix it.
	if {[info exists tcl_platform(debug)]} {
	    set file [file join $dir plplot510d[info sharedlibextension]]
	} else {
	    set file [file join $dir plplot510[info sharedlibextension]]
	}
    }

    load $file Plplotter
# put core tcl scripts in path
    lappend auto_path $dir/tcl
    rename load_pkg_Plplotter {}
}

package ifneeded Plplotter 5 [list load_pkg_Plplotter $dir]

